import {
  Subscribable,
  focusManager,
  getLogger,
  isServer,
  isValidTimeout,
  noop,
  notifyManager,
  parseQueryArgs,
  replaceEqualDeep,
  timeUntilStale,
  useQueryClient
} from "./chunk.H7NODJQ4.js";
import {
  _extends,
  _inheritsLoose
} from "./chunk.TKNXGYBG.js";

// node_modules/react-query/es/core/utils.js
function shallowEqualObjects(a, b) {
  if (a && !b || b && !a) {
    return false;
  }
  for (var key in a) {
    if (a[key] !== b[key]) {
      return false;
    }
  }
  return true;
}
function getStatusProps(status) {
  return {
    status,
    isLoading: status === "loading",
    isSuccess: status === "success",
    isError: status === "error",
    isIdle: status === "idle"
  };
}

// node_modules/react-query/es/core/queryObserver.js
var QueryObserver = /* @__PURE__ */ function(_Subscribable) {
  _inheritsLoose(QueryObserver2, _Subscribable);
  function QueryObserver2(client, options) {
    var _this;
    _this = _Subscribable.call(this) || this;
    _this.client = client;
    _this.options = options;
    _this.initialDataUpdateCount = 0;
    _this.initialErrorUpdateCount = 0;
    _this.trackedProps = [];
    _this.bindMethods();
    _this.setOptions(options);
    return _this;
  }
  var _proto = QueryObserver2.prototype;
  _proto.bindMethods = function bindMethods() {
    this.remove = this.remove.bind(this);
    this.refetch = this.refetch.bind(this);
  };
  _proto.onSubscribe = function onSubscribe() {
    if (this.listeners.length === 1) {
      this.updateQuery();
      this.currentQuery.addObserver(this);
      if (this.willFetchOnMount()) {
        this.executeFetch();
      }
      this.updateResult();
      this.updateTimers();
    }
  };
  _proto.onUnsubscribe = function onUnsubscribe() {
    if (!this.listeners.length) {
      this.destroy();
    }
  };
  _proto.willLoadOnMount = function willLoadOnMount() {
    return this.options.enabled !== false && !this.currentQuery.state.dataUpdatedAt && !(this.currentQuery.state.status === "error" && this.options.retryOnMount === false);
  };
  _proto.willRefetchOnMount = function willRefetchOnMount() {
    return this.options.enabled !== false && this.currentQuery.state.dataUpdatedAt > 0 && (this.options.refetchOnMount === "always" || this.options.refetchOnMount !== false && this.isStale());
  };
  _proto.willFetchOnMount = function willFetchOnMount() {
    return this.willLoadOnMount() || this.willRefetchOnMount();
  };
  _proto.willFetchOnReconnect = function willFetchOnReconnect() {
    return this.options.enabled !== false && (this.options.refetchOnReconnect === "always" || this.options.refetchOnReconnect !== false && this.isStale());
  };
  _proto.willFetchOnWindowFocus = function willFetchOnWindowFocus() {
    return this.options.enabled !== false && (this.options.refetchOnWindowFocus === "always" || this.options.refetchOnWindowFocus !== false && this.isStale());
  };
  _proto.willFetchOptionally = function willFetchOptionally() {
    return this.options.enabled !== false && this.isStale();
  };
  _proto.isStale = function isStale() {
    return this.currentQuery.isStaleByTime(this.options.staleTime);
  };
  _proto.destroy = function destroy() {
    this.listeners = [];
    this.clearTimers();
    this.currentQuery.removeObserver(this);
  };
  _proto.setOptions = function setOptions(options) {
    this.previousOptions = this.options;
    this.options = this.client.defaultQueryObserverOptions(options);
    if (typeof this.options.enabled !== "undefined" && typeof this.options.enabled !== "boolean") {
      throw new Error("Expected enabled to be a boolean");
    }
    if (!this.options.queryKey) {
      this.options.queryKey = this.previousOptions.queryKey;
    }
    var didUpdateQuery = this.updateQuery();
    var optionalFetch;
    var updateResult;
    var updateStaleTimeout;
    var updateRefetchInterval;
    if (didUpdateQuery) {
      optionalFetch = true;
      updateResult = true;
      updateStaleTimeout = true;
      updateRefetchInterval = true;
    }
    if (this.options.enabled !== false && this.previousOptions.enabled === false) {
      optionalFetch = true;
    }
    if (this.options.select !== this.previousOptions.select) {
      updateResult = true;
    }
    if (this.options.enabled !== this.previousOptions.enabled || this.options.staleTime !== this.previousOptions.staleTime) {
      updateStaleTimeout = true;
    }
    if (this.options.enabled !== this.previousOptions.enabled || this.options.refetchInterval !== this.previousOptions.refetchInterval) {
      updateRefetchInterval = true;
    }
    if (this.hasListeners()) {
      if (optionalFetch) {
        this.optionalFetch();
      }
    }
    if (updateResult) {
      this.updateResult();
    }
    if (this.hasListeners()) {
      if (updateStaleTimeout) {
        this.updateStaleTimeout();
      }
      if (updateRefetchInterval) {
        this.updateRefetchInterval();
      }
    }
    this.previousOptions = this.options;
  };
  _proto.getCurrentResult = function getCurrentResult() {
    return this.currentResult;
  };
  _proto.getTrackedCurrentResult = function getTrackedCurrentResult() {
    return this.trackedCurrentResult;
  };
  _proto.getNextResult = function getNextResult(options) {
    var _this2 = this;
    return new Promise(function(resolve, reject) {
      var unsubscribe = _this2.subscribe(function(result) {
        if (!result.isFetching) {
          unsubscribe();
          if (result.isError && (options == null ? void 0 : options.throwOnError)) {
            reject(result.error);
          } else {
            resolve(result);
          }
        }
      });
    });
  };
  _proto.getCurrentQuery = function getCurrentQuery() {
    return this.currentQuery;
  };
  _proto.remove = function remove() {
    this.client.getQueryCache().remove(this.currentQuery);
  };
  _proto.refetch = function refetch(options) {
    return this.fetch(options);
  };
  _proto.fetch = function fetch(fetchOptions) {
    var _this3 = this;
    return this.executeFetch(fetchOptions).then(function() {
      _this3.updateResult();
      return _this3.currentResult;
    });
  };
  _proto.optionalFetch = function optionalFetch() {
    if (this.willFetchOptionally()) {
      this.executeFetch();
    }
  };
  _proto.executeFetch = function executeFetch(fetchOptions) {
    this.updateQuery();
    var promise = this.currentQuery.fetch(this.options, fetchOptions);
    if (!(fetchOptions == null ? void 0 : fetchOptions.throwOnError)) {
      promise = promise.catch(noop);
    }
    return promise;
  };
  _proto.updateStaleTimeout = function updateStaleTimeout() {
    var _this4 = this;
    this.clearStaleTimeout();
    if (isServer || this.currentResult.isStale || !isValidTimeout(this.options.staleTime)) {
      return;
    }
    var time = timeUntilStale(this.currentResult.dataUpdatedAt, this.options.staleTime);
    var timeout = time + 1;
    this.staleTimeoutId = setTimeout(function() {
      if (!_this4.currentResult.isStale) {
        _this4.updateResult();
      }
    }, timeout);
  };
  _proto.updateRefetchInterval = function updateRefetchInterval() {
    var _this5 = this;
    this.clearRefetchInterval();
    if (isServer || this.options.enabled === false || !isValidTimeout(this.options.refetchInterval)) {
      return;
    }
    this.refetchIntervalId = setInterval(function() {
      if (_this5.options.refetchIntervalInBackground || focusManager.isFocused()) {
        _this5.executeFetch();
      }
    }, this.options.refetchInterval);
  };
  _proto.updateTimers = function updateTimers() {
    this.updateStaleTimeout();
    this.updateRefetchInterval();
  };
  _proto.clearTimers = function clearTimers() {
    this.clearStaleTimeout();
    this.clearRefetchInterval();
  };
  _proto.clearStaleTimeout = function clearStaleTimeout() {
    clearTimeout(this.staleTimeoutId);
    this.staleTimeoutId = void 0;
  };
  _proto.clearRefetchInterval = function clearRefetchInterval() {
    clearInterval(this.refetchIntervalId);
    this.refetchIntervalId = void 0;
  };
  _proto.getNewResult = function getNewResult() {
    var _this$previousQueryRe;
    var state = this.currentQuery.state;
    var isFetching = state.isFetching, status = state.status;
    var isPreviousData = false;
    var isPlaceholderData = false;
    var data;
    var dataUpdatedAt = state.dataUpdatedAt;
    var error = state.error;
    var errorUpdatedAt = state.errorUpdatedAt;
    if (!this.hasListeners() && this.willFetchOnMount()) {
      isFetching = true;
      if (!dataUpdatedAt) {
        status = "loading";
      }
    }
    if (this.options.keepPreviousData && !state.dataUpdateCount && ((_this$previousQueryRe = this.previousQueryResult) == null ? void 0 : _this$previousQueryRe.isSuccess) && status !== "error") {
      data = this.previousQueryResult.data;
      dataUpdatedAt = this.previousQueryResult.dataUpdatedAt;
      status = this.previousQueryResult.status;
      isPreviousData = true;
    } else if (this.options.select && typeof state.data !== "undefined") {
      var _this$currentResultSt, _this$previousOptions;
      if (this.currentResult && state.data === ((_this$currentResultSt = this.currentResultState) == null ? void 0 : _this$currentResultSt.data) && this.options.select === ((_this$previousOptions = this.previousOptions) == null ? void 0 : _this$previousOptions.select)) {
        data = this.currentResult.data;
      } else {
        try {
          data = this.options.select(state.data);
          if (this.options.structuralSharing !== false) {
            var _this$currentResult;
            data = replaceEqualDeep((_this$currentResult = this.currentResult) == null ? void 0 : _this$currentResult.data, data);
          }
        } catch (selectError) {
          getLogger().error(selectError);
          error = selectError;
          errorUpdatedAt = Date.now();
          status = "error";
        }
      }
    } else {
      data = state.data;
    }
    if (typeof this.options.placeholderData !== "undefined" && typeof data === "undefined" && status === "loading") {
      var placeholderData = typeof this.options.placeholderData === "function" ? this.options.placeholderData() : this.options.placeholderData;
      if (typeof placeholderData !== "undefined") {
        status = "success";
        data = placeholderData;
        isPlaceholderData = true;
      }
    }
    var result = _extends({}, getStatusProps(status), {
      data,
      dataUpdatedAt,
      error,
      errorUpdatedAt,
      failureCount: state.fetchFailureCount,
      isFetched: state.dataUpdateCount > 0 || state.errorUpdateCount > 0,
      isFetchedAfterMount: state.dataUpdateCount > this.initialDataUpdateCount || state.errorUpdateCount > this.initialErrorUpdateCount,
      isFetching,
      isLoadingError: status === "error" && state.dataUpdatedAt === 0,
      isPlaceholderData,
      isPreviousData,
      isRefetchError: status === "error" && state.dataUpdatedAt !== 0,
      isStale: this.isStale(),
      refetch: this.refetch,
      remove: this.remove
    });
    return result;
  };
  _proto.shouldNotifyListeners = function shouldNotifyListeners(prevResult, result) {
    var _this6 = this;
    var _this$options = this.options, notifyOnChangeProps = _this$options.notifyOnChangeProps, notifyOnChangePropsExclusions = _this$options.notifyOnChangePropsExclusions;
    if (prevResult === result) {
      return false;
    }
    if (!prevResult) {
      return true;
    }
    if (!notifyOnChangeProps && !notifyOnChangePropsExclusions) {
      return true;
    }
    var keys = Object.keys(result);
    var includedProps = notifyOnChangeProps === "tracked" ? this.trackedProps : notifyOnChangeProps;
    var _loop = function _loop2(i2) {
      var key = keys[i2];
      var changed = prevResult[key] !== result[key];
      var isIncluded = includedProps == null ? void 0 : includedProps.some(function(x) {
        return x === key;
      });
      var isExcluded = notifyOnChangePropsExclusions == null ? void 0 : notifyOnChangePropsExclusions.some(function(x) {
        return x === key;
      });
      if (changed) {
        if (notifyOnChangePropsExclusions && isExcluded) {
          return "continue";
        }
        if (!notifyOnChangeProps || isIncluded || notifyOnChangeProps === "tracked" && _this6.trackedProps.length === 0) {
          return {
            v: true
          };
        }
      }
    };
    for (var i = 0; i < keys.length; i++) {
      var _ret = _loop(i);
      if (_ret === "continue")
        continue;
      if (typeof _ret === "object")
        return _ret.v;
    }
    return false;
  };
  _proto.updateResult = function updateResult(action) {
    var _this7 = this;
    var prevResult = this.currentResult;
    var result = this.getNewResult();
    this.currentResultState = this.currentQuery.state;
    if (shallowEqualObjects(result, prevResult)) {
      return;
    }
    this.currentResult = result;
    if (this.options.notifyOnChangeProps === "tracked") {
      var addTrackedProps = function addTrackedProps2(prop) {
        if (!_this7.trackedProps.includes(prop)) {
          _this7.trackedProps.push(prop);
        }
      };
      this.trackedCurrentResult = {};
      Object.keys(result).forEach(function(key) {
        Object.defineProperty(_this7.trackedCurrentResult, key, {
          configurable: false,
          enumerable: true,
          get: function get() {
            addTrackedProps(key);
            return result[key];
          }
        });
      });
    }
    var notifyOptions = {
      cache: true
    };
    if ((action == null ? void 0 : action.type) === "success") {
      notifyOptions.onSuccess = true;
    } else if ((action == null ? void 0 : action.type) === "error") {
      notifyOptions.onError = true;
    }
    if (this.shouldNotifyListeners(prevResult, result)) {
      notifyOptions.listeners = true;
    }
    this.notify(notifyOptions);
  };
  _proto.updateQuery = function updateQuery() {
    var prevQuery = this.currentQuery;
    var query = this.client.getQueryCache().build(this.client, this.options);
    if (query === prevQuery) {
      return false;
    }
    this.previousQueryResult = this.currentResult;
    this.currentQuery = query;
    this.initialDataUpdateCount = query.state.dataUpdateCount;
    this.initialErrorUpdateCount = query.state.errorUpdateCount;
    if (this.hasListeners()) {
      prevQuery == null ? void 0 : prevQuery.removeObserver(this);
      this.currentQuery.addObserver(this);
    }
    return true;
  };
  _proto.onQueryUpdate = function onQueryUpdate(action) {
    this.updateResult(action);
    if (this.hasListeners()) {
      this.updateTimers();
    }
  };
  _proto.notify = function notify(notifyOptions) {
    var _this8 = this;
    notifyManager.batch(function() {
      if (notifyOptions.onSuccess) {
        _this8.options.onSuccess == null ? void 0 : _this8.options.onSuccess(_this8.currentResult.data);
        _this8.options.onSettled == null ? void 0 : _this8.options.onSettled(_this8.currentResult.data, null);
      } else if (notifyOptions.onError) {
        _this8.options.onError == null ? void 0 : _this8.options.onError(_this8.currentResult.error);
        _this8.options.onSettled == null ? void 0 : _this8.options.onSettled(void 0, _this8.currentResult.error);
      }
      if (notifyOptions.listeners) {
        _this8.listeners.forEach(function(listener) {
          listener(_this8.currentResult);
        });
      }
      if (notifyOptions.cache) {
        _this8.client.getQueryCache().notify(_this8.currentQuery);
      }
    });
  };
  return QueryObserver2;
}(Subscribable);

// node_modules/react-query/es/react/QueryErrorResetBoundary.js
import React from "react";
function createValue() {
  var _isReset = false;
  return {
    clearReset: function clearReset() {
      _isReset = false;
    },
    reset: function reset() {
      _isReset = true;
    },
    isReset: function isReset() {
      return _isReset;
    }
  };
}
var QueryErrorResetBoundaryContext = /* @__PURE__ */ React.createContext(createValue());
var useQueryErrorResetBoundary = function useQueryErrorResetBoundary2() {
  return React.useContext(QueryErrorResetBoundaryContext);
};

// node_modules/react-query/es/react/useBaseQuery.js
import React3 from "react";

// node_modules/react-query/es/react/useIsMounted.js
import React2 from "react";
function useIsMounted() {
  var mountedRef = React2.useRef(false);
  var isMounted = React2.useCallback(function() {
    return mountedRef.current;
  }, []);
  React2[isServer ? "useEffect" : "useLayoutEffect"](function() {
    mountedRef.current = true;
    return function() {
      mountedRef.current = false;
    };
  }, []);
  return isMounted;
}

// node_modules/react-query/es/react/useBaseQuery.js
function useBaseQuery(options, Observer) {
  var isMounted = useIsMounted();
  var queryClient = useQueryClient();
  var errorResetBoundary = useQueryErrorResetBoundary();
  var defaultedOptions = queryClient.defaultQueryObserverOptions(options);
  if (defaultedOptions.onError) {
    defaultedOptions.onError = notifyManager.batchCalls(defaultedOptions.onError);
  }
  if (defaultedOptions.onSuccess) {
    defaultedOptions.onSuccess = notifyManager.batchCalls(defaultedOptions.onSuccess);
  }
  if (defaultedOptions.onSettled) {
    defaultedOptions.onSettled = notifyManager.batchCalls(defaultedOptions.onSettled);
  }
  if (defaultedOptions.suspense) {
    if (typeof defaultedOptions.staleTime !== "number") {
      defaultedOptions.staleTime = 1e3;
    }
    if (!errorResetBoundary.isReset()) {
      defaultedOptions.retryOnMount = false;
    }
  }
  var observerRef = React3.useRef();
  var observer = observerRef.current || new Observer(queryClient, defaultedOptions);
  observerRef.current = observer;
  if (observer.hasListeners()) {
    observer.setOptions(defaultedOptions);
  }
  var currentResult = observer.getCurrentResult();
  var _React$useState = React3.useState(currentResult), setCurrentResult = _React$useState[1];
  React3.useEffect(function() {
    errorResetBoundary.clearReset();
    return observer.subscribe(notifyManager.batchCalls(function(result) {
      if (isMounted()) {
        setCurrentResult(result);
      }
    }));
  }, [observer, errorResetBoundary, isMounted]);
  if (observer.options.suspense || observer.options.useErrorBoundary) {
    if (observer.options.suspense && currentResult.isLoading) {
      errorResetBoundary.clearReset();
      var unsubscribe = observer.subscribe();
      throw observer.refetch().finally(unsubscribe);
    }
    if (currentResult.isError) {
      throw currentResult.error;
    }
  }
  return observer.options.notifyOnChangeProps === "tracked" ? observer.getTrackedCurrentResult() : currentResult;
}

// node_modules/react-query/es/react/useQuery.js
function useQuery(arg1, arg2, arg3) {
  var parsedOptions = parseQueryArgs(arg1, arg2, arg3);
  return useBaseQuery(parsedOptions, QueryObserver);
}

// src/runtime/functions/server.ts
import {
  createContext,
  createElement,
  useContext
} from "react";
var ServerQueryContext = createContext(void 0);

export {
  React,
  createValue,
  useIsMounted,
  ServerQueryContext,
  QueryErrorResetBoundaryContext,
  useQuery,
  useQueryErrorResetBoundary,
  QueryObserver,
  useBaseQuery,
  createElement,
  useContext,
  getStatusProps
};
