import { ReactHTML, CSSProperties } from 'react';
import { Context } from 'twind';
export { MDXProvider, MDXProviderComponents, useMDXComponents } from '@mdx-js/react';

declare type StyledIntrinsicFactories = {
    [TIntrinsic in keyof ReactHTML]: StyledHTML<TIntrinsic>;
};
interface StyledElements extends StyledIntrinsicFactories {
    <TIntrinsic extends keyof ReactHTML>(elementType: TIntrinsic): StyledHTML<TIntrinsic>;
    <T extends keyof ReactHTML>(elementType: T, strings: TemplateStringsArray, ...interpolations: readonly MaybeThunk<MaybeArray<CSSProperties | string | number | Falsy>>[]): ReactHTML[T];
    <T extends keyof ReactHTML>(elementType: T, tokens: MaybeThunk<MaybeArray<CSSProperties | Falsy>>): ReactHTML[T];
    <T extends keyof ReactHTML>(elementType: T, ...tokens: readonly MaybeThunk<CSSProperties | Falsy>[]): ReactHTML[T];
}
declare type Falsy = '' | 0 | -0 | false | null | undefined | void;
declare type MaybeArray<T> = T | readonly T[];
declare type MaybeThunk<T> = T | ((context: Context) => T);
interface StyledHTML<T extends keyof ReactHTML> {
    (strings: TemplateStringsArray, ...interpolations: readonly MaybeThunk<MaybeArray<CSSProperties | string | number | Falsy>>[]): ReactHTML[T];
    (tokens: MaybeThunk<MaybeArray<CSSProperties | Falsy>>): ReactHTML[T];
    (...tokens: readonly MaybeThunk<CSSProperties | Falsy>[]): ReactHTML[T];
}
declare const styled: StyledElements;

export { StyledElements, StyledIntrinsicFactories, styled };
